@@ -12,11 +12,18 @@ pub struct Attribute {
     pub attr_type: AttributeType,
     pub is_pii: bool,
     pub translations: HashMap<Language, AttributeTranslation>,
+    pub mapping: Option<String>,
     pub encoding: Option<Encoding>,
     pub format: Option<String>,
+    pub metric_system: Option<String>,
     pub unit: Option<String>,
     pub entry_codes: Option<EntryCodes>,
+    pub entry_codes_mapping: Option<Vec<String>>,
     pub sai: Option<String>,
+    pub condition: Option<String>,
+    pub dependencies: Option<Vec<String>>,
+    pub cardinality: Option<String>,
+    pub conformance: Option<String>,
 }
 
 pub struct AttributeBuilder {
@@ -31,11 +38,18 @@ impl AttributeBuilder {
                 attr_type,
                 is_pii: false,
                 translations: HashMap::new(),
+                mapping: None,
                 encoding: None,
                 format: None,
+                metric_system: None,
                 unit: None,
                 entry_codes: None,
+                entry_codes_mapping: None,
                 sai: None,
+                condition: None,
+                dependencies: None,
+                cardinality: None,
+                conformance: None,
             },
         }
     }
@@ -45,11 +59,36 @@ impl AttributeBuilder {
         self
     }
 
+    pub fn add_condition(
+        mut self,
+        condition: String,
+        dependencies: Vec<String>,
+    ) -> AttributeBuilder {
+        self.attribute.condition = Some(condition);
+        self.attribute.dependencies = Some(dependencies);
+        self
+    }
+
+    pub fn add_cardinality(mut self, cardinality: String) -> AttributeBuilder {
+        self.attribute.cardinality = Some(cardinality);
+        self
+    }
+
+    pub fn add_conformance(mut self, conformance: String) -> AttributeBuilder {
+        self.attribute.conformance = Some(conformance);
+        self
+    }
+
     pub fn add_encoding(mut self, encoding: Encoding) -> AttributeBuilder {
         self.attribute.encoding = Some(encoding);
         self
     }
 
+    pub fn add_mapping(mut self, mapping: String) -> AttributeBuilder {
+        self.attribute.mapping = Some(mapping);
+        self
+    }
+
     pub fn add_sai(mut self, sai: String) -> AttributeBuilder {
         self.attribute.sai = Some(sai);
         self
@@ -60,7 +99,8 @@ impl AttributeBuilder {
         self
     }
 
-    pub fn add_unit(mut self, unit: String) -> AttributeBuilder {
+    pub fn add_unit(mut self, metric_system: String, unit: String) -> AttributeBuilder {
+        self.attribute.metric_system = Some(metric_system);
         self.attribute.unit = Some(unit);
         self
     }
@@ -86,6 +126,11 @@ impl AttributeBuilder {
         self
     }
 
+    pub fn add_entry_codes_mapping(mut self, mapping: Vec<String>) -> AttributeBuilder {
+        self.attribute.entry_codes_mapping = Some(mapping);
+        self
+    }
+
     pub fn add_entries(mut self, entries: Entries) -> AttributeBuilder {
         match entries {
             Entries::Sai(lang_sai) => {
@@ -214,12 +259,22 @@ impl AttributeTranslation {
 #[derive(Serialize, Deserialize, Debug, Clone, Copy)]
 pub enum AttributeType {
     Boolean,
+    #[serde(rename = "Array[Boolean]")]
+    ArrayBoolean,
     Binary,
+    #[serde(rename = "Array[Binary]")]
+    ArrayBinary,
     Text,
-    Numeric,
-    Date,
-    #[serde(rename = "SAI")]
-    Sai,
     #[serde(rename = "Array[Text]")]
     ArrayText,
+    Numeric,
+    #[serde(rename = "Array[Numeric]")]
+    ArrayNumeric,
+    Date,
+    #[serde(rename = "Array[Date]")]
+    ArrayDate,
+    #[serde(rename = "SAI")]
+    Sai,
+    #[serde(rename = "Array[SAI]")]
+    ArraySai,
 }
