@@ -4,6 +4,8 @@ use wasm_bindgen::prelude::*;
 #[wasm_bindgen]
 #[derive(Serialize, Deserialize, Debug, Clone, Copy)]
 pub enum Encoding {
+    #[serde(rename = "base64")]
+    Base64,
     #[serde(rename = "utf-8")]
     Utf8,
     #[serde(rename = "iso-8859-1")]
