@@ -23,6 +23,13 @@ const PII_FLAG_INDEX: u32 = 3;
 const ENCODING_INDEX: u32 = 4;
 const FORMAT_INDEX: u32 = 5;
 const ENTRY_CODES_INDEX: u32 = 6;
+const CONDITION_INDEX: u32 = 7;
+const DEPENDENCIES_INDEX: u32 = 8;
+const CARDINALITY_INDEX: u32 = 9;
+const CONFORMANCE_INDEX: u32 = 10;
+const UNIT_INDEX: u32 = 11;
+const ATTRIBUTE_MAPPING_INDEX: u32 = 12;
+const ENTRY_CODE_MAPPING_INDEX: u32 = 13;
 
 const LABEL_INDEX: u32 = 3;
 const ENTRIES_INDEX: u32 = 4;
@@ -185,6 +192,74 @@ pub fn parse(
                 attribute_builder = attribute_builder.add_entry_codes(entry_codes);
             }
         }
+
+        if let Some(DataType::String(condition_value)) =
+            main_sheet.get_value((attr_index, CONDITION_INDEX))
+        {
+            if let Some(DataType::String(dependencies_value)) =
+                main_sheet.get_value((attr_index, DEPENDENCIES_INDEX))
+            {
+                attribute_builder = attribute_builder.add_condition(
+                    condition_value.clone(),
+                    dependencies_value
+                        .split(",")
+                        .collect::<Vec<&str>>()
+                        .iter()
+                        .map(|c| c.to_string())
+                        .collect(),
+                );
+            }
+        }
+
+        if let Some(DataType::Float(cardinality_value)) =
+            main_sheet.get_value((attr_index, CARDINALITY_INDEX))
+        {
+            attribute_builder =
+                attribute_builder.add_cardinality(cardinality_value.to_string().clone());
+        }
+
+        if let Some(DataType::String(conformance_value)) =
+            main_sheet.get_value((attr_index, CONFORMANCE_INDEX))
+        {
+            attribute_builder = attribute_builder.add_conformance(conformance_value.clone());
+        }
+
+        if let Some(DataType::String(unit_value)) = main_sheet.get_value((attr_index, UNIT_INDEX)) {
+            let mut metric_system = String::new();
+            let mut unit = unit_value.clone();
+
+            let mut splitted: Vec<String> = unit_value
+                .split("|")
+                .collect::<Vec<&str>>()
+                .iter()
+                .map(|c| c.to_string())
+                .collect();
+            if splitted.len() > 1 {
+                unit = splitted.pop().unwrap();
+                metric_system = splitted.join("|");
+            }
+
+            attribute_builder = attribute_builder.add_unit(metric_system, unit);
+        }
+
+        if let Some(DataType::String(mapping_value)) =
+            main_sheet.get_value((attr_index, ATTRIBUTE_MAPPING_INDEX))
+        {
+            attribute_builder = attribute_builder.add_mapping(mapping_value.clone());
+        }
+
+        if let Some(DataType::String(mapping_value)) =
+            main_sheet.get_value((attr_index, ENTRY_CODE_MAPPING_INDEX))
+        {
+            attribute_builder = attribute_builder.add_entry_codes_mapping(
+                mapping_value
+                    .split("|")
+                    .collect::<Vec<&str>>()
+                    .iter()
+                    .map(|c| c.to_string())
+                    .collect(),
+            );
+        }
         attribute_builders.push((attr_index, attribute_builder));
     }
 
